function dBp = cri(R,dAp)
//CRI:  Compositional Rule of Inference, based on fuzzy relation matrix
//      R and observation vector Ap, using Zadeh's inference CRI the
//      decision vector Bp is obtained.
//
//                        [Bp] = CRI(R,Ap)
//
//      Example: Suppose A and B are defied as:
//
//                   A=[1 .5 .1 0  0], B=[0  0 .1 .5 1]
//
//      Then fuzzy relation matrix R related to fuzzy implication A->B
//      is:(Mamdani implication relation)
//
//                          | 0  0  .1 .5  1 |
//                          | 0  0  .1 .5 .5 |
//                        R=| 0  0  .1 .1 .1 |
//                          | 0  0   0  0  0 |
//                          | 0  0   0  0  0 |
//                             B --------->
//
//      Let the observation value be Ap=[0 0 1 0 0], the decision vector
//      returns Bp=[0  0 .1 .1 .1].
//                                                       See also IMPLY.


// FISLAB: Fuzzy Inference Systems toolbox for SCILAB
// Created for MATLAB by 
//	(c) A. Lotfi, University of Queensland (Email: lotfia@s1.elec.uq.oz.au) 13-10-93
// Translated to SCILAB 
//	by G. Ortega, European Space Agency (Email: gortega@estec.esa.nl) 25-07-96
// The program has been tested on SCILAB version 2.2, PC Pentium, runing Linux 1.3.30

dAp=dAp(:);
[m,n]=size(R);

if (max(max(R)) > 1) | (max(max(dAp)) > 1)
  error('Grade of membership function should not be more than one')
end


if m ~= length(dAp)
  error('Observation vector Ap and R should have proper dimension')
end


//In the next comming lines we are Calculating the MATLAB function MAX
Int=min(R,(diag(dAp)*ones(m,n)));  //Transformating the matrix min(R,(diag(dAp)*ones(m,n))) into a long row vector
Int=Int(1:m*n);    // Int is now a long vector
dBp=[];             // Initializing the exit vector of this function

//Constructing the MATLAB function MAX for a matrix
for i=1:n:n*m-m+1
  dBp = [dBp max(Int(i:i+m-1))]
end
